##  Next Step
[Step 3: Discover and Prioritize Technology Obsolescence Risks](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-discover-prioritize-risks?locale=en-US&state=PRODUCTION&version=CLOUD "Analyze and prioritize technological risks using insights obtained from reports.")
